@@ -10,10 +10,10 @@ import unittest
 import subprocess
 import sys
 import tarfile
+import stat
 
-sys.path.append('..')
-from libmat import mat
 import test
+from libmat import mat
 
 
 class TestRemovecli(test.MATTest):
@@ -24,14 +24,22 @@ class TestRemovecli(test.MATTest):
     def test_remove(self):
         """make sure that the cli remove all compromizing meta"""
         for _, dirty in self.file_list:
-            subprocess.call(['../mat', '--add2archive', dirty])
+            subprocess.call(['mat', '--add2archive', dirty])
             current_file = mat.create_class_file(dirty, False, add2archive=True, low_pdf_quality=True)
             self.assertTrue(current_file.is_clean())
 
+    def test_remove_fileformat_specific_options(self):
+        """ test metadata removal with fileformat-specific options """
+        for _, dirty in self.file_list:  # can't be faster than that :/
+            if dirty.endswith('pdf'):
+                subprocess.call(['mat', '--low-pdf-quality', dirty])
+                current_file = mat.create_class_file(dirty, False, low_pdf_quality=True)
+                self.assertTrue(current_file.is_clean())
+
     def test_remove_empty(self):
         """Test removal with clean files\n"""
         for clean, _ in self.file_list:
-            subprocess.call(['../mat', '--add2archive', clean])
+            subprocess.call(['mat', '--add2archive', clean])
             current_file = mat.create_class_file(clean, False, add2archive=True, low_pdf_quality=True)
             self.assertTrue(current_file.is_clean())
 
@@ -44,7 +52,7 @@ class TestListcli(test.MATTest):
     def test_list_clean(self):
         """check if get_meta returns meta"""
         for clean, _ in self.file_list:
-            proc = subprocess.Popen(['../mat', '-d', clean],
+            proc = subprocess.Popen(['mat', '-d', clean],
                                     stdout=subprocess.PIPE)
             stdout, _ = proc.communicate()
             self.assertEqual(str(stdout).strip('\n'), "[+] File %s \
@@ -53,7 +61,7 @@ class TestListcli(test.MATTest):
     def test_list_dirty(self):
         """check if get_meta returns all the expected meta"""
         for _, dirty in self.file_list:
-            proc = subprocess.Popen(['../mat', '-d', dirty],
+            proc = subprocess.Popen(['mat', '-d', dirty],
                                     stdout=subprocess.PIPE)
             stdout, _ = proc.communicate()
             self.assertNotEqual(str(stdout), "[+] File %s :\n No\
@@ -68,7 +76,7 @@ class TestisCleancli(test.MATTest):
     def test_clean(self):
         """test is_clean on clean files"""
         for clean, _ in self.file_list:
-            proc = subprocess.Popen(['../mat', '-c', clean],
+            proc = subprocess.Popen(['mat', '-c', clean],
                                     stdout=subprocess.PIPE)
             stdout, _ = proc.communicate()
             self.assertEqual(str(stdout).strip('\n'), '[+] %s is clean' % clean)
@@ -76,7 +84,7 @@ class TestisCleancli(test.MATTest):
     def test_dirty(self):
         """test is_clean on dirty files"""
         for _, dirty in self.file_list:
-            proc = subprocess.Popen(['../mat', '-c', dirty],
+            proc = subprocess.Popen(['mat', '-c', dirty],
                                     stdout=subprocess.PIPE)
             stdout, _ = proc.communicate()
             self.assertEqual(str(stdout).strip('\n'), '[+] %s is not clean' % dirty)
@@ -89,41 +97,75 @@ class TestFileAttributes(unittest.TestCase):
 
     def test_not_writtable(self):
         """ test MAT's behaviour on non-writable file"""
-        proc = subprocess.Popen(['../mat', 'not_writtable'],
+        proc = subprocess.Popen(['mat', 'not_writtable'],
                                 stdout=subprocess.PIPE)
         stdout, _ = proc.communicate()
-        self.assertEqual(str(stdout).strip('\n'), '[-] %s is not writable' % 'not_writtable')
+        self.assertEqual(str(stdout).strip('\n'), '[-] Unable to process not_writtable')
 
     def test_not_exist(self):
         """ test MAT's behaviour on non-existent file"""
-        proc = subprocess.Popen(['../mat', 'ilikecookies'],
+        proc = subprocess.Popen(['mat', 'ilikecookies'],
                                 stdout=subprocess.PIPE)
         stdout, _ = proc.communicate()
-        self.assertEqual(str(stdout).strip('\n'), 'Unable to process  %s' % 'ilikecookies')
+        self.assertEqual(str(stdout).strip('\n'), '[-] Unable to process ilikecookies')
 
     def test_empty(self):
         """ test MAT's behaviour on empty file"""
-        proc = subprocess.Popen(['../mat', 'empty_file'], stdout=subprocess.PIPE)
+        proc = subprocess.Popen(['mat', 'empty_file'], stdout=subprocess.PIPE)
         stdout, _ = proc.communicate()
-        self.assertEqual(str(stdout).strip('\n'), 'Unable to process  %s' % 'ilikecookies')
+        self.assertEqual(str(stdout).strip('\n'), '[-] Unable to process empty_file')
+
+    def test_not_readable(self):
+        """ test MAT's behaviour on non-writable file"""
+        open('non_readable', 'a').close()
+        os.chmod('non_readable', 0 & stat.S_IWRITE)
+        proc = subprocess.Popen(['mat', 'non_readable'], stdout=subprocess.PIPE)
+        stdout, _ = proc.communicate()
+        os.remove('non_readable')
 
 
 class TestUnsupported(test.MATTest):
+    """ test MAT's behaviour on unsupported files """
     def test_abort_unsupported(self):
         """ test if the cli aborts on unsupported files
         """
         tarpath = os.path.join(self.tmpdir, "test.tar.bz2")
         tar = tarfile.open(tarpath, "w")
-        for f in ('../mat.desktop', '../README.security', '../setup.py'):
-            tar.add(f, f[3:])  # trim '../'
+        for f in ('libtest.py', 'test.py', 'clitest.py'):
+            tar.add(f, f)
         tar.close()
-        proc = subprocess.Popen(['../mat', tarpath], stdout=subprocess.PIPE)
+        proc = subprocess.Popen(['mat', tarpath], stdout=subprocess.PIPE)
         stdout, _ = proc.communicate()
-        self.assertTrue('It contains unsupported filetypes:' \
-                        '\n- mat.desktop\n- README.security\n- setup.py\n'
+        self.assertTrue('It contains unsupported filetypes:'
+                        '\n- libtest.py\n- test.py\n- clitest.py\n'
                         in str(stdout))
 
 
+class TestHelp(test.MATTest):
+    """ Test the different ways to trigger help """
+    def test_dash_h(self):
+        """ test help invocation with `-h` and `--help` """
+        proc = subprocess.Popen(['mat', '-h'], stdout=subprocess.PIPE)
+        stdout, _ = proc.communicate()
+        self.assertTrue('show this help message and exit' in stdout)
+
+        proc = subprocess.Popen(['mat', '--help'], stdout=subprocess.PIPE)
+        stdout, _ = proc.communicate()
+        self.assertTrue('show this help message and exit' in stdout)
+
+    def test_no_argument(self):
+        """ test help invocation when no argument is provided """
+        proc = subprocess.Popen(['mat'], stdout=subprocess.PIPE)
+        stdout, _ = proc.communicate()
+        self.assertTrue('show this help message and exit' in stdout)
+
+    def test_wrong_argument(self):
+        """ Test MAT's behaviour on wrong argument """
+        proc = subprocess.Popen(['mat', '--obviously-wrong-argument'], stderr=subprocess.PIPE)
+        _, stderr = proc.communicate()
+        self.assertTrue(('usage: mat [-h]' and ' error: unrecognized arguments:') in stderr)
+
+
 def get_tests():
     """ Return every clitests"""
     suite = unittest.TestSuite()
@@ -131,4 +173,6 @@ def get_tests():
     suite.addTest(unittest.makeSuite(TestListcli))
     suite.addTest(unittest.makeSuite(TestisCleancli))
     suite.addTest(unittest.makeSuite(TestUnsupported))
+    suite.addTest(unittest.makeSuite(TestFileAttributes))
+    suite.addTest(unittest.makeSuite(TestHelp))
     return suite
