@@ -7,13 +7,13 @@
 
 import os
 import sys
+import stat
 import shutil
 import tarfile
 import tempfile
-import test
 import unittest
 
-sys.path.append('..')
+import test
 import libmat
 
 
@@ -29,6 +29,15 @@ class TestRemovelib(test.MATTest):
             current_file = libmat.mat.create_class_file(dirty, False, add2archive=True)
             self.assertTrue(current_file.is_clean())
 
+    def test_remove_fileformat_specific_options(self):
+        """ test metadata removal with fileformat-specific options """
+        for _, dirty in self.file_list:  # can't be faster than that :/
+            if dirty.endswith('pdf'):
+                current_file = libmat.mat.create_class_file(dirty, False, add2archive=True, low_pdf_quality=True)
+                current_file.remove_all()
+                current_file = libmat.mat.create_class_file(dirty, False, add2archive=True, low_pdf_quality=True)
+                self.assertTrue(current_file.is_clean())
+
     def test_remove_empty(self):
         """Test removal with clean files"""
         for clean, _ in self.file_list:
@@ -87,6 +96,17 @@ class TestFileAttributes(unittest.TestCase):
         self.assertFalse(libmat.mat.create_class_file('empty_file', False, add2archive=True))
         os.remove('empty_file')
 
+    def test_not_writtable(self):
+        """ test MAT's behaviour on non-writable file"""
+        self.assertFalse(libmat.mat.create_class_file('not_writtable', False, add2archive=True))
+
+    def test_not_readable(self):
+        """ test MAT's behaviour on non-readable file"""
+        open('non_readable', 'a').close()
+        os.chmod('non_readable', 0 | stat.S_IWRITE)
+        self.assertFalse(libmat.mat.create_class_file('non_readable', False, add2archive=True))
+        os.remove('non_readable')
+
 
 class TestSecureRemove(unittest.TestCase):
     """ Test the secure_remove function
@@ -155,12 +175,12 @@ class TestArchiveProcessing(test.MATTest):
         """
         tarpath = os.path.join(self.tmpdir, "test.tar.bz2")
         tar = tarfile.open(tarpath, "w")
-        for f in ('../mat.desktop', '../README.security', '../setup.py'):
-            tar.add(f, f[3:])  # trim '../'
+        for f in ('libtest.py', 'test.py', 'clitest.py'):
+            tar.add(f, f)
         tar.close()
         current_file = libmat.mat.create_class_file(tarpath, False, add2archive=False)
         unsupported_files = set(current_file.is_clean(list_unsupported=True))
-        self.assertEqual(unsupported_files, {'mat.desktop', 'README.security', 'setup.py'})
+        self.assertEqual(unsupported_files, {'libtest.py', 'test.py', 'clitest.py'})
 
     def test_archive_unwritable_content(self):
         path = os.path.join(self.tmpdir, './unwritable_content.zip')
