@@ -14,6 +14,7 @@ import glob
 import sys
 import tempfile
 import unittest
+import subprocess
 
 VERBOSITY = 15
 
@@ -27,6 +28,8 @@ FILE_LIST = zip(clean, dirty)
 try:  # PDF render processing
     import cairo
     import gi
+
+    gi.require_version('Poppler', '0.18')
     from gi.repository import Poppler
     import pdfrw
 except ImportError:
@@ -39,6 +42,11 @@ except ImportError:
     FILE_LIST.remove(('clean é.mp3', 'dirty é.mp3'))
     FILE_LIST.remove(('clean é.flac', 'dirty é.flac'))
 
+try:  # exiftool
+    subprocess.check_output(['exiftool', '-ver'])
+except OSError:
+    FILE_LIST.remove(('clean é.tif', 'dirty é.tif'))
+
 
 class MATTest(unittest.TestCase):
     """
@@ -69,13 +77,40 @@ class MATTest(unittest.TestCase):
         shutil.rmtree(self.tmpdir)
 
 
-if __name__ == '__main__':
+def run_all_tests():
+    """
+    This method will run all tests, both for cli and lib.
+    The imports of clitest and libtest are done here because
+    we're modifying the PATH (technically, it's two path:
+    the one used to spawn the `mat` process, and the one for Python import)
+    in the main function.
+    """
     import clitest
     import libtest
+    suite = unittest.TestSuite()
+    suite.addTests(clitest.get_tests())
+    suite.addTests(libtest.get_tests())
 
-    SUITE = unittest.TestSuite()
-    SUITE.addTests(clitest.get_tests())
-    SUITE.addTests(libtest.get_tests())
+    return unittest.TextTestRunner(verbosity=VERBOSITY).run(suite).wasSuccessful()
 
-    ret = unittest.TextTestRunner(verbosity=VERBOSITY).run(SUITE).wasSuccessful()
-    sys.exit(ret is False)
+
+def set_local():
+    """ Monkey patch paths to run the testsuite on the _local_
+    version of MAT. See `run_all_tests` for more information about
+    what paths we're changing and why.
+    """
+    os.environ['PATH'] = '..:' + os.environ['PATH']
+    sys.path.append('..')
+
+
+if __name__ == '__main__':
+    import argparse
+
+    parser = argparse.ArgumentParser(description='MAT testsuite')
+    parser.add_argument('-s', '--system', action='store_true',
+                        help='Test the system-wide version of mat')
+
+    if parser.parse_args().system is False:
+        set_local()
+
+    sys.exit(run_all_tests() is False)
